=======
History
=======

0.1.3 ()
------------------
* HTTP Auth
* Basic search inflate
* relationshipAttributes

0.1.2 (2018-03-27)
------------------

* Bug fixes
* Response is returned after entity creation (easier to figure out the guid)

0.1.1 (2018-03-07)
------------------

* Bug fixes
* Most of the resources have been implemented (except RelationshipREST)
* Basic authentication (only the Basic token is sent on the network)

0.1.0 (2018-01-09)
------------------

* First push.


